#include <stdio.h>
#include <stdlib.h>

typedef struct _cvor{
	int vrednost;
	struct _cvor *sledeci;
}cvor;

void greska(){
	printf("-1");
	exit(EXIT_FAILURE);
}

//dodaj
	//na pocetak, na kraj, u sortirnu listu
//obrisi
//ispis
//oslobodi memoriju

//bitno je da izdvojimo u funkciju jer nam je cesto potrebno
cvor* kreiraj_novi(int v){
	cvor *x = malloc(sizeof(cvor));
	if(x == NULL)
		greska();
	x->vrednost = v;
	x->sledeci = NULL;
	return x;
}

//glava liste predstavlja celu listu
//dodajemo na pocetak, glava liste menja
//imamo listu l1 (glava), i vrednost v1,
//kada dodamo v1 u listu glava ce se promeniti
//i novu glavu liste moramo da vratimo
//imamo 2 pristupa:
cvor* dodaj_na_pocetak(cvor *g, int v){
	cvor *n = kreiraj_novi(v);
	n->sledeci = g;
	return n;
}
void dodaj_na_pocetak2(cvor **g, int v){
	cvor *n = kreiraj_novi(v);
	n->sledeci = *g;
	*g = n;
}

void ispis(cvor *g){
	//uslov zaustavljanja je prazna lista
	if(g == NULL)
		return;
	
	//stampamo vrednost u tekucem cvoru
	printf("%d ", g->vrednost);
	//ispis ostatka liste rekurzivno
	ispis(g->sledeci);
}

void ispis_iter(cvor *g){
	//sve dok ne dodjemo do kraja liste
	while(g){
		printf("%d ", g->vrednost);
		g = g->sledeci;
	}
}

cvor* dodaj_na_kraj(cvor *g, int v){
	if(g == NULL)
		return kreiraj_novi(v);
	
	//ako lista nije prazna znamo jedino da je g != NULL
	//ne znamo da li sledeci postoji ili je sledci NULL
	//i nista dalje, ali to nam  nije bitno
	
	g->sledeci = dodaj_na_kraj(g->sledeci, v);
	return g;
}

cvor* dodaj_na_kraj_iter(cvor *g, int v){
	if(g == NULL)
		return kreiraj_novi(v);
	
	//posto ce g da se menja cuvam glavu liste
	cvor *tmp = g;
	
	//ako g nije NULL, trazimo prvi element u listi,
	//takav da je njegov sledeci == NULL, to je u stvari 
	//zadnji element
	//na njega treba da nakacimo novi el. koji kreiramo
	while(g->sledeci != NULL)
		g = g->sledeci;
	
	//nakon ovog while-a smo nasli poslednji el.
	//g sledeci je NULL, a mi ga menjamo da bude novi el.
	g->sledeci = kreiraj_novi(v);
	return tmp;
}

cvor *oslobodi(cvor *g){
	if(g == NULL)
		return NULL;
	
	//prvo oslobadjamo ostatak liste
	oslobodi(g->sledeci);
	
	//posle brisemo glavu liste
	free(g);
	
	return NULL;
}

cvor* ucitaj_listu(){
	int x;
	cvor *lista = NULL;
	while(1){
		scanf("%d", &x);
		if(x == 0)
			break;
		
		lista = dodaj_na_kraj(lista, x);
	}
	return lista;
}

//funckija koja brise sva pojavljivanja vrednosti x u listi
cvor* obrisi(cvor *l, int x){
	//mi radimo iterativno
	//rekurzivna varijanta za domaci
	
	if(l == NULL)
		return NULL;
	
	cvor *telo_liste = obrisi(l->sledeci, x);
	
	if(l->vrednost == x){
		free(l);
		return telo_liste;
	}
	else{
		l->sledeci = telo_liste;
		return l;
	}
}

cvor *dodaj_u_sortiranu_listu(cvor *g, int v){
	if(g == NULL)
		return kreiraj_novi(v);
	
	if(v < g->vrednost){
		//novi cvor se dodaje pre glave
		return dodaj_na_pocetak(g, v);
	}
	else{
		g->sledeci = dodaj_u_sortiranu_listu(g->sledeci, v);
		return g;
	}
}

cvor *ucitaj_sortiranu_listu(){
	int x;
	cvor *lista = NULL;
	while(1){
		scanf("%d", &x);
		if(x == 0)
			break;
		
		lista = dodaj_u_sortiranu_listu(lista, x);
	}
	return lista;
}

cvor* spoj_sortirano(cvor *l1, cvor *l2){
	if(l1 == NULL)
		return l2;
	if(l2 == NULL)
		return l1;
	
	//ako program dodje do ove linije znaci da nisu ni l1, ni l2
	//jednaki NULL
	if(l1->vrednost < l2->vrednost){
		l1->sledeci = spoj_sortirano(l1->sledeci, l2);
		return l1;
	}
	else{
		l2->sledeci = spoj_sortirano(l1, l2->sledeci);
		return l2;
	}
}

int main(){
	
	cvor *l1 = ucitaj_sortiranu_listu();
	cvor *l2 = ucitaj_sortiranu_listu();
	
	ispis(l1);
	printf("\n");
	
	ispis(l2);
	printf("\n");
	
	cvor *l3 = spoj_sortirano(l1, l2);
	
	ispis(l3);
	printf("\n");
	
	l3 = oslobodi(l3);
	
	
	/****************
	cvor *l = ucitaj_listu();
	
	ispis(l);
	printf("\n");
	
	l = obrisi(l, 3);
	
	ispis(l);
	printf("\n");
	
	l = oslobodi(l);
	************************/
	
	/**********************************
	//ovo je test za citanje liste, sa pocetak i sa kraja
	//ispis, i brisanje liste
	cvor *l1 = NULL; //MORA NA POCETKU DA SE POSTAVI NA NULL!!!!
	cvor *l2 = NULL;
	
	int x;
	while(1){
		scanf("%d", &x);
		if(x == 0)
			break;
		
		//testiramo dodaj na kraj:
		l1 = dodaj_na_kraj(l1, x);
		l2 = dodaj_na_kraj_iter(l2, x);
		
		//testirali smo dodaj na pocetak
		//obe rade isto, samo sto prva vraca novu listu
		//a druga menja argument
		//l1 = dodaj_na_pocetak(l1, x);
		//dodaj_na_pocetak2(&l2, x);
		
		//svi zadaci mogu da se rade na 2 nacina, prvi navedeni
		//i drugi, mi (na vezbama) cemo raditi prvi nacin,
		//kada se vraca nova lista
	}
	
	ispis(l1);
	printf("\n");
	ispis_iter(l2);
	printf("\n");
	
	l1 = oslobodi(l1);
	l2 = oslobodi(l2);
	***************************************/
}